@@ -1,18 +1,13 @@
 #!/usr/bin/env bash
 
 # Script to setup a local solana-test-validator with the stake pool program
+# given a maximum number of validators and a file path to store the list of
+# test validator vote accounts.
 
 cd "$(dirname "$0")"
 max_validators=$1
 validator_list=$2
 
-keys_dir=keys
-mkdir -p $keys_dir
-if test -f $validator_list
-then
-  rm $validator_list
-fi
-
 create_keypair () {
   if test ! -f $1
   then
@@ -20,11 +15,11 @@ create_keypair () {
   fi
 }
 
-build_program () {
+build_stake_pool_program () {
   cargo build-bpf --manifest-path ../../program/Cargo.toml
 }
 
-setup_validator() {
+setup_test_validator() {
   solana-test-validator --bpf-program SPoo1Ku8WFXoNDMHPsrGSTSG1Y47rzgn41SLUNakuHy ../../../target/deploy/spl_stake_pool.so --quiet --reset --slots-per-epoch 32 &
   pid=$!
   solana config set --url http://127.0.0.1:8899
@@ -40,17 +35,27 @@ create_vote_accounts () {
   do
     create_keypair $keys_dir/identity_$number.json
     create_keypair $keys_dir/vote_$number.json
-    solana create-vote-account $keys_dir/vote_$number.json $keys_dir/identity_$number.json --commission 1
+    create_keypair $keys_dir/withdrawer_$number.json
+    solana create-vote-account $keys_dir/vote_$number.json $keys_dir/identity_$number.json $keys_dir/withdrawer_$number.json --commission 1
     vote_pubkey=$(solana-keygen pubkey $keys_dir/vote_$number.json)
     echo $vote_pubkey >> $validator_list
   done
 }
 
-echo "Building on-chain program"
-build_program
 
-echo "Setting up local validator"
-setup_validator
+echo "Setup keys directory and clear old validator list file if found"
+keys_dir=keys
+mkdir -p $keys_dir
+if test -f $validator_list
+then
+  rm $validator_list
+fi
 
-echo "Creating vote accounts"
+echo "Building on-chain stake pool program"
+build_stake_pool_program
+
+echo "Setting up local test validator"
+setup_test_validator
+
+echo "Creating vote accounts, these accounts be added to the stake pool"
 create_vote_accounts $max_validators $validator_list
