@@ -7,11 +7,8 @@ use {
         rpc_config::{RpcAccountInfoConfig, RpcProgramAccountsConfig},
         rpc_filter::{Memcmp, MemcmpEncodedBytes, RpcFilterType},
     },
-    solana_program::{borsh::try_from_slice_unchecked, program_pack::Pack, pubkey::Pubkey},
-    spl_stake_pool::{
-        stake_program,
-        state::{StakePool, ValidatorList},
-    },
+    solana_program::{borsh::try_from_slice_unchecked, program_pack::Pack, pubkey::Pubkey, stake},
+    spl_stake_pool::state::{StakePool, ValidatorList},
 };
 
 type Error = Box<dyn std::error::Error>;
@@ -70,50 +67,13 @@ pub fn get_token_mint(
 pub(crate) fn get_stake_state(
     rpc_client: &RpcClient,
     stake_address: &Pubkey,
-) -> Result<stake_program::StakeState, Error> {
+) -> Result<stake::state::StakeState, Error> {
     let account_data = rpc_client.get_account_data(stake_address)?;
     let stake_state = deserialize(account_data.as_slice())
         .map_err(|err| format!("Invalid stake account {}: {}", stake_address, err))?;
     Ok(stake_state)
 }
 
-pub(crate) fn get_stake_accounts_by_withdraw_authority(
-    rpc_client: &RpcClient,
-    withdraw_authority: &Pubkey,
-) -> Result<Vec<(Pubkey, u64, stake_program::StakeState)>, ClientError> {
-    rpc_client
-        .get_program_accounts_with_config(
-            &stake_program::id(),
-            #[allow(clippy::needless_update)] // TODO: Remove after updating to solana >=1.6.10
-            RpcProgramAccountsConfig {
-                filters: Some(vec![RpcFilterType::Memcmp(Memcmp {
-                    offset: 44, // 44 is Withdrawer authority offset in stake account stake
-                    bytes: MemcmpEncodedBytes::Binary(format!("{}", withdraw_authority)),
-                    encoding: None,
-                })]),
-                account_config: RpcAccountInfoConfig {
-                    encoding: Some(UiAccountEncoding::Base64),
-                    ..RpcAccountInfoConfig::default()
-                },
-                ..RpcProgramAccountsConfig::default()
-            },
-        )
-        .map(|accounts| {
-            accounts
-                .into_iter()
-                .filter_map(
-                    |(address, account)| match deserialize(account.data.as_slice()) {
-                        Ok(stake_state) => Some((address, account.lamports, stake_state)),
-                        Err(err) => {
-                            eprintln!("Invalid stake account data for {}: {}", address, err);
-                            None
-                        }
-                    },
-                )
-                .collect()
-        })
-}
-
 pub(crate) fn get_stake_pools(
     rpc_client: &RpcClient,
 ) -> Result<Vec<(Pubkey, StakePool, ValidatorList)>, ClientError> {
@@ -123,7 +83,7 @@ pub(crate) fn get_stake_pools(
             RpcProgramAccountsConfig {
                 filters: Some(vec![RpcFilterType::Memcmp(Memcmp {
                     offset: 0, // 0 is the account type
-                    bytes: MemcmpEncodedBytes::Binary("2".to_string()),
+                    bytes: MemcmpEncodedBytes::Base58("2".to_string()),
                     encoding: None,
                 })]),
                 account_config: RpcAccountInfoConfig {
